@@ -5,7 +5,7 @@ use warnings;
 package Kavorka::Parameter;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.020';
+our $VERSION   = '0.021';
 our @CARP_NOT  = qw( Kavorka::Signature Kavorka::Sub Kavorka );
 
 use Carp qw( croak );
@@ -76,7 +76,6 @@ sub BUILD
 		coerce    => 1,
 		copy      => 1,
 		invocant  => 1,
-		optional  => 1,
 		rw        => 1,
 		slurpy    => 1,
 	};
@@ -185,6 +184,13 @@ sub parse
 		lex_read_space;
 	}
 	
+	if (lex_peek eq '\\')
+	{
+		$traits{ref_alias} = 1;
+		lex_read(1);
+		lex_read_space;
+	}
+	
 	if (lex_peek(3) =~ /\A(my|our)/)
 	{
 		$varkind = $1;
@@ -192,6 +198,13 @@ sub parse
 		lex_read_space;
 	}
 	
+	if (lex_peek eq '\\')
+	{
+		croak("cannot be a double-ref-alias") if $traits{ref_alias}++;
+		lex_read(1);
+		lex_read_space;
+	}
+	
 	lex_stuff(':') if $saw_colon; # re-insert colon
 	$peek = lex_peek;
 	
@@ -224,8 +237,6 @@ sub parse
 		lex_read_space;
 	}
 	
-	$traits{slurpy} = 1 if defined($varname) && $varname =~ /\A[\@\%]/;
-	
 	if (lex_peek eq '!')
 	{
 		$traits{optional} = 0;
@@ -271,6 +282,11 @@ sub parse
 	$traits{optional} //= $traits{_optional};
 	delete($traits{_optional});
 	
+	$traits{slurpy} = 1
+		if defined($varname)
+		&& !$traits{ref_alias}
+		&& $varname =~ /\A[\@\%]/;
+	
 	return $class->new(
 		%args,
 		type           => $type,
@@ -310,12 +326,7 @@ sub sanity_check
 		croak("Bad name for package variable: $name") if length($name) < 2;
 	}
 	
-	croak("Bad parameter $name") if $self->invocant && $self->optional;
 	croak("Bad parameter $name") if $self->invocant && $self->slurpy;
-	croak("Parameter $name cannot be an alias and coerce") if $traits->{alias} && $traits->{coerce};
-	croak("Parameter $name cannot be an alias and a copy") if $traits->{alias} && $traits->{copy};
-	croak("Parameter $name cannot be an alias and locked") if $traits->{alias} && $traits->{locked};
-	croak("Parameter $name cannot be rw and ro") if $traits->{ro} && $traits->{rw};
 }
 
 sub injection
@@ -448,6 +459,30 @@ sub _injection_extract_and_coerce_value
 	wantarray ? ($val, $condition) : $val;
 }
 
+sub _injection_default_value
+{
+	my $self = shift;
+	my ($fallback) = @_;
+	
+	return sprintf('$%s::PARAMS[%d]{default}->()', __PACKAGE__, $self->ID) if $self->default;
+	return $fallback if defined $fallback;
+	
+	return sprintf(
+		'Carp::croak(sprintf q/Named parameter `%%s` is required/, %s)',
+		B::perlstring($self->named_names->[0]),
+	) if $self->named;
+	
+	return sprintf(
+		'Carp::croak(q/Invocant %s is required/)',
+		$self->name,
+	) if $self->invocant;
+	
+	return sprintf(
+		'Carp::croak(q/Positional parameter %d is required/)',
+		$self->position,
+	);
+}
+
 sub _injection_extract_value
 {
 	my $self = shift;
@@ -455,7 +490,6 @@ sub _injection_extract_value
 	
 	my $condition;
 	my $val;
-	my $default = $self->default ? sprintf('$%s::PARAMS[%d]->{default}->()', __PACKAGE__, $self->ID) : '';
 	my $slurpy_style = '';
 	
 	if ($self->slurpy)
@@ -480,7 +514,7 @@ sub _injection_extract_value
 					'do { use warnings FATAL => qw(all); my %%tmp = ($#_==%d && ref($_[%d]) eq q(HASH)) ? %%{$_[%d]} : @_[ %d .. $#_ ]; %s %%tmp ? %%tmp : (%s) }',
 					($ix) x 4,
 					$delete,
-					($default // ''),
+					$self->_injection_default_value('()'),
 				);
 			}
 			else
@@ -489,7 +523,7 @@ sub _injection_extract_value
 					'do { use warnings FATAL => qw(all); my %%tmp = @_[ %d .. $#_ ]; %%tmp ? @_[ %d .. $#_ ] : (%s) }',
 					$sig->last_position + 1,
 					$sig->last_position + 1,
-					($default // ''),
+					$self->_injection_default_value('()'),
 				);
 			}
 			$condition = 1;
@@ -503,7 +537,7 @@ sub _injection_extract_value
 				'($#_ >= %d) ? @_[ %d .. $#_ ] : (%s)',
 				$sig->last_position + 1,
 				$sig->last_position + 1,
-				($default // ''),
+				$self->_injection_default_value('()'),
 			);
 			$condition = 1;
 			$slurpy_style = '@';
@@ -517,11 +551,6 @@ sub _injection_extract_value
 	}
 	elsif ($self->named)
 	{
-		my $defaultish =
-			length($default) ? $default :
-			$self->optional  ? 'undef'  :
-			sprintf('Carp::croak(sprintf q/Named parameter `%%s` is required/, %s)', B::perlstring $self->named_names->[0]);
-		
 		no warnings 'uninitialized';
 		my $when = +{
 			'//='   => 'defined',
@@ -532,7 +561,7 @@ sub _injection_extract_value
 		$val = join '', map(
 			sprintf('%s($_{%s}) ? $_{%s} : ', $when, $_, $_),
 			map B::perlstring($_), @{$self->named_names}
-		), $defaultish;
+		), $self->_injection_default_value();
 		
 		$condition = join ' or ', map(
 			sprintf('%s($_{%s})', $when, $_),
@@ -541,18 +570,11 @@ sub _injection_extract_value
 	}
 	elsif ($self->invocant)
 	{
-		my $defaultish = sprintf('Carp::croak(q/Invocant %s is required/)', $self->name);
-		$val = sprintf('@_ ? shift(@_) : %s', $defaultish);
+		$val = sprintf('@_ ? shift(@_) : %s', $self->_injection_default_value());
 		$condition = 1;
 	}
 	else
 	{
-		my $pos        = $self->position;
-		my $defaultish =
-			length($default) ? $default :
-			$self->optional  ? 'undef'  :
-			sprintf('Carp::croak(q/Positional parameter %d is required/)', $pos);
-		
 		no warnings 'uninitialized';
 		my $when = +{
 			'//='   => 'defined($_[%d])',
@@ -560,12 +582,12 @@ sub _injection_extract_value
 			'='     => '($#_ >= %d)',
 		}->{ $self->default_when } || '($#_ >= %d)';
 		
-		$val = sprintf($when.' ? $_[%d] : %s', $pos, $pos, $defaultish);
-		
+		my $pos = $self->position;
+		$val       = sprintf($when.' ? $_[%d] : %s', $pos, $pos, $self->_injection_default_value());
 		$condition = sprintf($when, $self->position);
 	}
 	
-	$condition = 1 if length $default;
+	$condition = 1 if $self->_injection_default_value('@@') ne '@@';
 	
 	wantarray ? ($val, $condition) : $val;
 }
